==> meatadata-auto-v_0.1.tar.bz2: meatadata-auto-v_0.1/fso_metadata/api_call.py <==
import itertools
from typing import Type, Union

import pandas as pd

from api_classes import (
    AgentId,
    AgentsList,
    call_api,
    CodeList,
    ContentConfiguration,
    ContentConfigurationIdentifier,
    DatasetId,
    DatasetIdDistributions,
    DatasetIdentifier,
    DatasetIdentifierDistributions,
    DatasetsList,
    DistributionId,
    DistributionsList,
    NomenclatureMultipleLevels,
    NomenclatureOneLevel,
    NomenclaturePathNodes,
    NomenclatureSearch,
)
from utils import stringify_filters


###############################################################
########################## i14y APIs ##########################
###############################################################

def get_codelist(identifier: str, export_format: str="SDMX-ML", version_format: float=2.1, annotations: bool=False) -> Union[dict, pd.DataFrame]:
    '''
    Get a codelist based on an identifier
    Parameters:
        - identifier (str): the codelist's identifier
        - export_format (str, default="SDMX-ML"): the export's format. Available are CSV, XLSX, SDMX-ML or SDMX-JSON.
        - version_format (float, default=2.1): the export format's version (2.0 or 2.1 when format is SDMX-ML).
        - annotations (bool, default=False): flag to include annotations
        
    Returns:
        - response (pd.DataFrame or dict) based on the export format
            - a pd.DataFrame if export_format was CSV or XLSX
            - a dictionnary if export_format was SDMX-ML or SDMX-JSON.
    '''
    return call_api(CodeList, identifier, export_format, version_format, annotations)


def get_content_creation() -> dict:
    '''
    Get the display information for the available configured content
    Returns:
        - response (dict): the configured content's display information
    '''
    return call_api(ContentConfiguration)


def get_identifier_content(identifier) -> dict:
    '''
    Get a nomenclature information based on its identifier
    Parameters:
        - identifier (str): the nomenclature's identifier
    Returns:
        - response (dict): the nomenclature's information
    '''
    return call_api(ContentConfigurationIdentifier, identifier)


def get_nomenclature_path_nodes(identifier: str, path: str, filters: dict, language: str = 'fr') -> dict:
    '''
    Get the nodes of a path within a nomenclature
    Parameters:
        - identifier (str): the nomenclature's identifier
        - path (str): the path leading to the nodes
        - filters (dict, default={}): the filters to apply
        - language (str, default='fr'): the language of the response data. Available are 'fr', 'de', 'it', 'en'.
    Returns:
        - response: dictionnary of the nodes
    '''
    return call_api(NomenclaturePathNodes, identifier, path, filters, language)


def get_nomenclature_one_level(identifier: str, level_number: int, filters: dict, language: str = 'fr', annotations: bool = False) -> pd.DataFrame:
    '''
    Get one level of a nomenclature
    Parameters:
        - identifier (str): nomenclature's identifier
        - level_number (int): level to export
        - filter (default={}): additionnal filters
        - language (str, default='fr'): response data's language Available are 'fr', 'de', 'it', 'en'.
        - annotations (bool, default=False): flag to include annotations
    Returns:
        - response (pd.DataFrame): dataframe with 3 columns (Code, Parent and Name in the selected language)
    '''
    parameters = f'language={language}&level={level_number}&annotations={str(annotations).lower()}&{stringify_filters(filters)}'
    return call_api(NomenclatureOneLevel, identifier, parameters)


def get_nomenclature_multiple_levels(identifier: str, level_from: int, level_to: int, filters: dict, language: str = 'fr', annotations: bool = False) -> pd.DataFrame:
    '''
    Get multiple levels of a nomenclature (from `level_from` to `level_to`)
    Parameters:
        - identifier (str): nomenclature's identifier
        - level_from (int): the 1st level to include
        - level_to (int): the last level to include
        - filter (default={}): additionnal filters
        - language (str, default='fr'): response data's language Available are 'fr', 'de', 'it', 'en'.
        - annotations (bool, default=False): flag to include annotations
    Returns:
        - response (pd.DataFrame): dataframe columns from `level_from` to `level_to` codes and additionnal data
    '''
    parameters = f'language={language}&levelFrom={level_from}&levelTo={level_to}&annotations={str(annotations).lower()}&{stringify_filters(filters)}'
    df = call_api(NomenclatureMultipleLevels, identifier, parameters)
    
    # fill sub groups rows with parent groups values
    group_columns = [*itertools.takewhile(lambda col: col != 'Code', df.columns)]
    df[group_columns[0]] = df[group_columns[0]].fillna(method="ffill")
    df[group_columns[1:]] = df.groupby([group_columns[0]])[group_columns[1:]].apply(lambda x: x.ffill())
        
    return df


def query_nomenclature(identifier: str, query: str, page_number: int, page_size: int, filters: dict, language: str) -> dict:
    '''
    Search query within a nomenclature
    Parameters:
        - identifier (str): the nomenclature's identifier
        - query (str): the search query
        - page_number (int): the number of the result page to return
        - page_size (int): the size of each page result
        - filter (default={}): additionnal filters
        - language (str, default='fr'): response data's language Available are 'fr', 'de', 'it', 'en'.
    Returns:
        - response (dict): the query result
    '''
    parameters = {'language': language, 'query': query, 'page': page_number, 'pageSize': page_size}
    parameters = {**parameters, **filters}
    return call_api(NomenclatureSearch, identifier, parameters)


###############################################################
########################## dcat APIs ##########################
###############################################################

def list_all_agents():
    '''
    List all agents
    Returns:
        - response (dict): all agents
    '''
    return call_api(AgentsList)


def get_agent_from_id(agent_id):
    '''
    Get the agent with the corresponding agent id
    Parameters:
        - agent_id (str): agent's id
    Returns:
        - response (dict): agent with this id
    '''
    return call_api(AgentId, agent_id)


def list_all_datasets():
    '''
    List all datasets
    Returns:
        - response (dict): list of all datasets 
    '''
    return call_api(DatasetsList)


def get_distributions_from_dataset_id(dataset_id: str):
    '''
    Get all distributions for the dataset with the corresponding dataset id
    Parameters:
        - dataset_id (str): dataset's id
    Returns:
        - response (dict): distributions for the dataset with dataset's id
    '''
    return call_api(DatasetIdDistributions, dataset_id)


def get_dataset_from_id(dataset_id: str):
    '''
    Get the dataset with the corresponding id
    Parameters:
        - dataset_id (str): dataset's id
    Returns:
        - response (dict): the dataset
    '''
    return call_api(DatasetId, dataset_id)


def get_dataset_from_identifier(identifier: str):
    '''
    Get the dataset with the corresponding identifier
    Parameters:
        - identidier (str): dataset's identifier
    Returns:
        - response (dict): the dataset
    '''
    return call_api(DatasetIdentifier, identifier)


def get_distributions_from_dataset_identifier(identifier: str):
    '''
    Get all distributions for the dataset with the corresponding dataset identifier.
    Parameters:
        - identidier (str): dataset's identifier
    Returns:
        - response (dict): all distributions for the dataset with the corresponding dataset identifier
    '''
    return call_api(DatasetIdentifierDistributions, identifier)


def list_all_distributions():
    '''
    List all distributions
    Returns:
        - response (dict): all distributions
    '''
    return call_api(DistributionsList)


def get_distribution_from_id(distribution_id: str):
    '''
    Get the distribution with the corresponding id
    Parameters:
        - distribution_id (str): distribution's id
    Returns:
        - response (dict): the distribution
    '''
    return call_api(DistributionId, distribution_id)

==> meatadata-auto-v_0.2.tar.bz2: meatadata-auto-v_0.2/fso_metadata/api_call.py <==
import itertools
from typing import Type, Union

import pandas as pd

from api_classes import (
    AgentId,
    AgentsList,
    call_api,
    CodeList,
    ContentConfiguration,
    ContentConfigurationIdentifier,
    DatasetId,
    DatasetIdDistributions,
    DatasetIdentifier,
    DatasetIdentifierDistributions,
    DatasetsList,
    DistributionId,
    DistributionsList,
    NomenclatureMultipleLevels,
    NomenclatureOneLevel,
    NomenclaturePathNodes,
    NomenclatureSearch,
)
from utils import stringify_filters


###############################################################
########################## i14y APIs ##########################
###############################################################

def get_codelist(
    identifier: str, 
    export_format: str="SDMX-ML", 
    version_format: float=2.1, 
    annotations: bool=False
) -> Union[dict, pd.DataFrame]:
    '''
    Get a codelist based on an identifier
    Parameters:
        - identifier (str): the codelist's identifier
        - export_format (str, default="SDMX-ML"): the export's format
           Available are CSV, XLSX, SDMX-ML or SDMX-JSON.
        - version_format (float, default=2.1): the export format's version 
          (2.0 or 2.1 when format is SDMX-ML).
        - annotations (bool, default=False): flag to include annotations
        
    Returns:
        - response (pd.DataFrame or dict) based on the export format
            - a pd.DataFrame if export_format was CSV or XLSX
            - a dictionnary if export_format was SDMX-ML or SDMX-JSON.
    '''
    return call_api(CodeList, identifier, export_format, version_format, annotations)


def get_content_creation() -> dict:
    '''
    Get the display information for the available configured content
    Returns:
        - response (dict): the configured content's display information
    '''
    return call_api(ContentConfiguration)


def get_identifier_content(identifier) -> dict:
    '''
    Get a nomenclature information based on its identifier
    Parameters:
        - identifier (str): the nomenclature's identifier
    Returns:
        - response (dict): the nomenclature's information
    '''
    return call_api(ContentConfigurationIdentifier, identifier)


def get_nomenclature_path_nodes(
    identifier: str, 
    path: str, filters: dict, 
    language: str = 'fr'
) -> dict:
    '''
    Get the nodes of a path within a nomenclature
    Parameters:
        - identifier (str): the nomenclature's identifier
        - path (str): the path leading to the nodes
        - filters (dict, default={}): the filters to apply
        - language (str, default='fr'): the language of the response data
            Available are 'fr', 'de', 'it', 'en'.
    Returns:
        - response: dictionnary of the nodes
    '''
    return call_api(NomenclaturePathNodes, identifier, path, filters, language)


def get_nomenclature_one_level(
    identifier: str, 
    level_number: int, 
    filters: dict, 
    language: str = 'fr', 
    annotations: bool = False
) -> pd.DataFrame:
    '''
    Get one level of a nomenclature
    Parameters:
        - identifier (str): nomenclature's identifier
        - level_number (int): level to export
        - filter (default={}): additionnal filters
        - language (str, default='fr'): response data's language
            Available are 'fr', 'de', 'it', 'en'.
        - annotations (bool, default=False): flag to include annotations
    Returns:
        - response (pd.DataFrame): dataframe with 3 columns 
            (Code, Parent and Name in the selected language)
    '''
    parameters = (
        f'language={language}'
        f'&level={level_number}'
        f'&annotations={str(annotations).lower()}'
        f'&{stringify_filters(filters)}'
    )
    return call_api(NomenclatureOneLevel, identifier, parameters)


def get_nomenclature_multiple_levels(
    identifier: str, 
    level_from: int, 
    level_to: int, 
    filters: dict, 
    language: str = 'fr', 
    annotations: bool = False
) -> pd.DataFrame:
    '''
    Get multiple levels of a nomenclature (from `level_from` to `level_to`)
    Parameters:
        - identifier (str): nomenclature's identifier
        - level_from (int): the 1st level to include
        - level_to (int): the last level to include
        - filter (default={}): additionnal filters
        - language (str, default='fr'): response data's language
            Available are 'fr', 'de', 'it', 'en'.
        - annotations (bool, default=False): flag to include annotations
    Returns:
        - response (pd.DataFrame): dataframe columns from `level_from` to `level_to` codes
    '''
    parameters = (
        f'language={language}'
        f'&levelFrom={level_from}'
        f'&levelTo={level_to}'
        f'&annotations={str(annotations).lower()}'
        f'&{stringify_filters(filters)}'
    )
    df = call_api(NomenclatureMultipleLevels, identifier, parameters)
    
    # fill sub groups rows with parent groups values
    group_columns = [*itertools.takewhile(lambda col: col != 'Code', df.columns)]
    df[group_columns[0]] = df[group_columns[0]].fillna(method="ffill")
    df[group_columns[1:]] = (
        df.groupby([group_columns[0]])[group_columns[1:]]
    ).apply(lambda x: x.ffill())
        
    return df


def query_nomenclature(
    identifier: str, 
    query: str, 
    page_number: int, 
    page_size: int, 
    filters: dict, 
    language: str
) -> dict:
    '''
    Search query within a nomenclature
    Parameters:
        - identifier (str): the nomenclature's identifier
        - query (str): the search query
        - page_number (int): the number of the result page to return
        - page_size (int): the size of each page result
        - filter (default={}): additionnal filters
        - language (str, default='fr'): response data's language 
            Available are 'fr', 'de', 'it', 'en'.
    Returns:
        - response (dict): the query result
    '''
    parameters = {
        'language': language, 
        'query': query, 
        'page': page_number, 
        'pageSize': page_size
    }
    parameters = {**parameters, **filters}
    return call_api(NomenclatureSearch, identifier, parameters)


###############################################################
########################## dcat APIs ##########################
###############################################################

def list_all_agents():
    '''
    List all agents
    Returns:
        - response (dict): all agents
    '''
    return call_api(AgentsList)


def get_agent_from_id(agent_id):
    '''
    Get the agent with the corresponding agent id
    Parameters:
        - agent_id (str): agent's id
    Returns:
        - response (dict): agent with this id
    '''
    return call_api(AgentId, agent_id)


def list_all_datasets():
    '''
    List all datasets
    Returns:
        - response (dict): list of all datasets 
    '''
    return call_api(DatasetsList)


def get_distributions_from_dataset_id(dataset_id: str):
    '''
    Get all distributions for the dataset with the corresponding dataset id
    Parameters:
        - dataset_id (str): dataset's id
    Returns:
        - response (dict): distributions for the dataset with dataset's id
    '''
    return call_api(DatasetIdDistributions, dataset_id)


def get_dataset_from_id(dataset_id: str):
    '''
    Get the dataset with the corresponding id
    Parameters:
        - dataset_id (str): dataset's id
    Returns:
        - response (dict): the dataset
    '''
    return call_api(DatasetId, dataset_id)


def get_dataset_from_identifier(identifier: str):
    '''
    Get the dataset with the corresponding identifier
    Parameters:
        - identidier (str): dataset's identifier
    Returns:
        - response (dict): the dataset
    '''
    return call_api(DatasetIdentifier, identifier)


def get_distributions_from_dataset_identifier(identifier: str):
    '''
    Get all distributions for the dataset with the corresponding dataset identifier.
    Parameters:
        - identidier (str): dataset's identifier
    Returns:
        - response (dict): all distributions for the dataset with the corresponding dataset identifier
    '''
    return call_api(DatasetIdentifierDistributions, identifier)


def list_all_distributions():
    '''
    List all distributions
    Returns:
        - response (dict): all distributions
    '''
    return call_api(DistributionsList)


def get_distribution_from_id(distribution_id: str):
    '''
    Get the distribution with the corresponding id
    Parameters:
        - distribution_id (str): distribution's id
    Returns:
        - response (dict): the distribution
    '''
    return call_api(DistributionId, distribution_id)
